<?php
/*
 * NwNewProducts
 *
 * Copyright(c) 2009-2012 NAKWEB CO.,LTD. All Rights Reserved.
 *
 * http://ec-cube.nakweb.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/**
 * 新着商品ブロック表示 のページクラス.
 *
 * @package NwNewProducts
 * @author NAKWEB CO.,LTD.
 */
class NwNewProducts extends SC_Plugin_Base {

    /**
     * コンストラクタ
     *
     */
    public function __construct(array $arrSelfInfo) {
        parent::__construct($arrSelfInfo);
    }

    /**
     * インストール
     * installはプラグインのインストール時に実行されます.
     * 引数にはdtb_pluginのプラグイン情報が渡されます.
     *
     * @param array $arrPlugin plugin_infoを元にDBに登録されたプラグイン情報(dtb_plugin)
     * @return void
     */
    function install($arrPlugin) {
        $objQuery = SC_Query_Ex::getSingletonInstance();

        // 画像ファイルは、html/plugin 以下にコピー
        if(copy(PLUGIN_UPLOAD_REALDIR . "NwNewProducts/logo.png", PLUGIN_HTML_REALDIR . "NwNewProducts/logo.png") === false) print_r("失敗");

		// PHPファイルは、html 以下にコピー
		if(copy(PLUGIN_UPLOAD_REALDIR . "NwNewProducts/bloc/new_products.php", HTML_REALDIR . "frontparts/bloc/new_products.php") === false) print_r("失敗");

		// TPLファイルは、data/Smarty/templates/default 以下にコピー
		if(copy(PLUGIN_UPLOAD_REALDIR . "NwNewProducts/templates/frontparts/bloc/new_products.tpl", TEMPLATE_REALDIR . "frontparts/bloc/new_products.tpl") === false) print_r("失敗");
    }

    /**
     * アンインストール
     * uninstallはアンインストール時に実行されます.
     * 引数にはdtb_pluginのプラグイン情報が渡されます.
     *
     * @param array $arrPlugin プラグイン情報の連想配列(dtb_plugin)
     * @return void
     */
    function uninstall($arrPlugin) {
        $objQuery = SC_Query_Ex::getSingletonInstance();

        $arrBlocId = $objQuery->getCol('bloc_id', "dtb_bloc", "device_type_id = ? AND plugin_id = ?", array(DEVICE_TYPE_PC , $arrPlugin['plugin_id']));
        $bloc_id = (int) $arrBlocId[0];
        // ブロックを削除する.
        $where = "device_type_id = ? AND bloc_id = ?";
        $objQuery->delete("dtb_blocposition", $where, array(DEVICE_TYPE_PC, $bloc_id));
        $objQuery->delete("dtb_bloc", $where, array(DEVICE_TYPE_PC, $bloc_id));

		if(SC_Helper_FileManager_Ex::deleteFile(PLUGIN_HTML_REALDIR . "NwNewProducts/logo.png") === false) print_r("失敗");
		if(SC_Helper_FileManager_Ex::deleteFile(HTML_REALDIR . "frontparts/bloc/new_products.php") === false) print_r("失敗");
		if(SC_Helper_FileManager_Ex::deleteFile(TEMPLATE_REALDIR . "frontparts/bloc/new_products.tpl") === false) print_r("失敗");
    }

    /**
     * アップデート
     * updateはアップデート時に実行されます.
     * 引数にはdtb_pluginのプラグイン情報が渡されます.
     *
     * @param array $arrPlugin プラグイン情報の連想配列(dtb_plugin)
     * @return void
     */
    function update($arrPlugin) {
        // nop
    }

    /**
     * 稼働
     * enableはプラグインを有効にした際に実行されます.
     * 引数にはdtb_pluginのプラグイン情報が渡されます.
     *
     * @param array $arrPlugin プラグイン情報の連想配列(dtb_plugin)
     * @return void
     */
    function enable($arrPlugin) {
        //プラグイン専用テーブルの作成
        $objQuery =& SC_Query_Ex::getSingletonInstance();
        $objQuery->begin();
        // dtb_blocにブロックを追加する.
        $sqlval_bloc = array();
        $sqlval_bloc['device_type_id'] = DEVICE_TYPE_PC;
        $sqlval_bloc['bloc_id'] = $objQuery->max('bloc_id', "dtb_bloc", "device_type_id = " . DEVICE_TYPE_PC) + 1;
        $sqlval_bloc['bloc_name'] = $arrPlugin['plugin_name'];
        $sqlval_bloc['tpl_path'] = "new_products.tpl";
        $sqlval_bloc['filename'] = "new_products";
        $sqlval_bloc['create_date'] = "CURRENT_TIMESTAMP";
        $sqlval_bloc['update_date'] = "CURRENT_TIMESTAMP";
        $sqlval_bloc['php_path'] = "frontparts/bloc/new_products.php";
        $sqlval_bloc['deletable_flg'] = 0;
        $sqlval_bloc['plugin_id'] = $arrPlugin['plugin_id'];
        $objQuery->insert("dtb_bloc", $sqlval_bloc);
        $objQuery->commit();
    }

    /**
     * 停止
     * disableはプラグインを無効にした際に実行されます.
     * 引数にはdtb_pluginのプラグイン情報が渡されます.
     *
     * @param array $arrPlugin プラグイン情報の連想配列(dtb_plugin)
     * @return void
     */
    function disable($arrPlugin) {
        $objQuery = SC_Query_Ex::getSingletonInstance();
        $arrBlocId = $objQuery->getCol('bloc_id', "dtb_bloc", "device_type_id = ? AND plugin_id = ?", array(DEVICE_TYPE_PC , $arrPlugin['plugin_id']));
        $bloc_id = (int) $arrBlocId[0];
        // ブロックを削除する.
        $where = "bloc_id = ?";
        $objQuery->delete("dtb_bloc", $where, array($bloc_id));
    }

    /**
     * 処理の介入箇所とコールバック関数を設定
     * registerはプラグインインスタンス生成時に実行されます
     *
     * @param SC_Helper_Plugin $objHelperPlugin
     */
    function register(SC_Helper_Plugin $objHelperPlugin) {
        $template_dir = PLUGIN_UPLOAD_REALDIR . 'NwNewProducts/templates/';
        $objHelperPlugin->setHeadNavi($template_dir . 'header.tpl');
    }

}
?>
